@@ -12,7 +12,7 @@ use WWW::GoKGS::Scraper::TournGames;
 use WWW::GoKGS::Scraper::TournInfo;
 use WWW::GoKGS::Scraper::TournList;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 sub new {
     my $class = shift;
@@ -28,6 +28,10 @@ sub html_filter {
     $_[0]->{html_filter} ||= sub { $_[0] };
 }
 
+sub result_filter {
+    $_[0]->{result_filter} ||= sub { $_[0] };
+}
+
 sub user_agent {
     my $self = shift;
     $self->{user_agent} ||= $self->_build_user_agent;
@@ -51,8 +55,9 @@ sub _build_scraper {
 
     +{ map { $_->base_uri->path => $_ } (
         WWW::GoKGS::Scraper::GameArchives->new(
-            user_agent  => $self->user_agent,
-            date_filter => $self->date_filter,
+            user_agent    => $self->user_agent,
+            date_filter   => $self->date_filter,
+            result_filter => $self->result_filter,
         ),
         WWW::GoKGS::Scraper::Top100->new(
             user_agent => $self->user_agent,
@@ -70,8 +75,9 @@ sub _build_scraper {
             date_filter => $self->date_filter,
         ),
         WWW::GoKGS::Scraper::TournGames->new(
-            user_agent  => $self->user_agent,
-            date_filter => $self->date_filter,
+            user_agent    => $self->user_agent,
+            date_filter   => $self->date_filter,
+            result_filter => $self->result_filter,
         ),
     )};
 }
@@ -131,28 +137,28 @@ WWW::GoKGS - KGS Go Server (http://www.gokgs.com/) Scraper
   my $gokgs = WWW::GoKGS->new;
 
   # Game archives
-  my $gameArchives1 = $gokgs->scrape( '/gameArchives.jsp?user=foo' );
-  my $gameArchives2 = $gokgs->game_archives->query( user => 'foo' );
+  my $game_archives_1 = $gokgs->scrape( '/gameArchives.jsp?user=foo' );
+  my $game_archives_2 = $gokgs->game_archives->query( user => 'foo' );
 
   # Top 100 players
-  my $top100Players1 = $gokgs->scrape( '/top100.jsp' );
-  my $top100Players2 = $gokgs->top_100->query;
+  my $top_100_1 = $gokgs->scrape( '/top100.jsp' );
+  my $top_100_2 = $gokgs->top_100->query;
 
   # List of tournaments 
-  my $tournList1 = $gokgs->scrape( '/tournList.jsp?year=2014' );
-  my $tournList2 = $gokgs->tourn_list->query( year => 2014 );
+  my $tourn_list_1 = $gokgs->scrape( '/tournList.jsp?year=2014' );
+  my $tourn_list_2 = $gokgs->tourn_list->query( year => 2014 );
 
   # Information for the tournament
-  my $tournInfo1 = $gokgs->scrape( '/tournInfo.jsp?id=123' );
-  my $tournInfo2 = $gokgs->tourn_info->query( id => 123 );
+  my $tourn_info_1 = $gokgs->scrape( '/tournInfo.jsp?id=123' );
+  my $tourn_info_2 = $gokgs->tourn_info->query( id => 123 );
 
-  # Tournament entrants
-  my $tournEntrants1 = $gokgs->scrape( '/tournEntrans.jsp?id=123&sort=n' );
-  my $tournEntrants2 = $gokgs->tourn_entrants->query( id => 123, sort => 'n' );
+  # The tournament entrants
+  my $tourn_entrants_1 = $gokgs->scrape( '/tournEntrans.jsp?id=123&sort=n' );
+  my $tourn_entrants_2 = $gokgs->tourn_entrants->query( id => 123, sort => 'n' );
 
-  # Tournament games
-  my $tournGames1 = $gokgs->scrape( '/tournGames.jsp?id=123&round=1' );
-  my $tournGames2 = $gokgs->tourn_games->query( id => 123, round => 1 );
+  # The tournament games
+  my $tourn_games_1 = $gokgs->scrape( '/tournGames.jsp?id=123&round=1' );
+  my $tourn_games_2 = $gokgs->tourn_games->query( id => 123, round => 1 );
 
 =head1 DESCRIPTION
 
@@ -194,8 +200,8 @@ resource. This attribute is read-only.
 
   my $gokgs = WWW::GoKGS->new(
       user_agent => LWP::UserAgent->new(
-          agent => 'MyAgent/1.00',
-      ),
+          agent => 'MyAgent/1.00'
+      )
   );
 
 =item $CodeRef = $gokgs->html_filter
@@ -210,7 +216,7 @@ This attribute is read-only.
           my $html = shift;
           $html =~ s/<.*?>//g; # strip HTML tags
           $html;
-      },
+      }
   );
 
 =item $CodeRef = $gokgs->date_filter
@@ -226,7 +232,29 @@ the filtered value. This attribute is read-only.
       date_filter => sub {
           my $date = shift; # => "2014-05-17T19:05Z"
           gmtime->strptime( $date, '%Y-%m-%dT%H:%MZ' );
-      },
+      }
+  );
+
+=item $CodeRef = $gokgs->result_filter
+
+=item $gokgs->result_filter( sub { my $result = shift; ... } )
+
+Can be used to get or set a game result filter. Defaults to an anonymous subref
+which just returns the given argument (C<sub { $_[0] }>). The callback is
+called with a game result string such as C<B+Resign>.
+The return value is used as the filtered value.
+
+  my $gokgs = WWW::GoKGS->new(
+      result_filter => sub {
+          my $result = shift; # => "B+Resign"
+
+          # I prefer "B+R" to "B+Resign", 
+          # while both of them are valid SGF-compatible format
+          return 'B+R' if $result eq 'B+Resign';
+          ...
+
+          $result;
+      }
   );
 
 =item $GameArchive = $gokgs->game_archives
@@ -272,7 +300,7 @@ This attribute is read-only.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/gameArchives.jsp?user=foo' );
-  my $gameArchives = $gokgs->game_archives->scrape( $uri );
+  my $game_archives = $gokgs->game_archives->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::GameArchives> for details.
 
@@ -283,7 +311,7 @@ See L<WWW::GoKGS::Scraper::GameArchives> for details.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/top100.jsp' );
-  my $top100 = $gokgs->top_100->scrape( $uri );
+  my $top_100 = $gokgs->top_100->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::Top100> for details.
 
@@ -294,7 +322,7 @@ See L<WWW::GoKGS::Scraper::Top100> for details.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/tournList.jsp?year=2014' );
-  my $tournList = $gokgs->tourn_list->scrape( $uri );
+  my $tourn_list = $gokgs->tourn_list->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::TournList> for details.
 
@@ -305,7 +333,7 @@ See L<WWW::GoKGS::Scraper::TournList> for details.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/tournInfo.jsp?id=123' );
-  my $tournInfo = $gokgs->tourn_info->scrape( $uri );
+  my $tourn_info = $gokgs->tourn_info->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::TournInfo> for details.
 
@@ -316,7 +344,7 @@ See L<WWW::GoKGS::Scraper::TournInfo> for details.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/tournEntrants.jsp?id=123&s=n' );
-  my $tournEntrants = $gokgs->tourn_entrants->scrape( $uri );
+  my $tourn_entrants = $gokgs->tourn_entrants->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::TournEntrants> for details.
 
@@ -327,7 +355,7 @@ See L<WWW::GoKGS::Scraper::TournEntrants> for details.
 A shortcut for:
 
   my $uri = URI->new( 'http://www.gokgs.com/tournGames.jsp?id=123&round=1' );
-  my $tournGames = $gokgs->tourn_games->scrape( $uri );
+  my $tourn_games = $gokgs->tourn_games->scrape( $uri );
 
 See L<WWW::GoKGS::Scraper::TournGames> for details.
 
