@@ -13,14 +13,12 @@ sub _build_base_uri {
 sub _build_scraper {
     my $self = shift;
     my $name = sub { s/ Round \d+ Games$// };
-    my $round = sub { m/ Round (\d+) Games$/ ? $1 : undef };
-    my $handicap = sub { m/ H(\d+)$/ ? $1 : undef };
-    my $board_size = sub { m/^(\d+)\x{d7}\d+ / ? $1 : undef };
+    my $round = sub { m/ Round (\d+) Games$/ ? int $1 : undef };
 
     my $player = sub {
         m/^([a-zA-Z0-9]+)(?: \[([^\]]+)\])?$/ 
-            ? { name => $1, rank => $2 || undef }
-            : {};
+            ? { name => $1, $2 ? (rank => $2) : () }
+            : undef;
     };
 
     my $start_time = sub {
@@ -37,8 +35,7 @@ sub _build_scraper {
         process '//td[2]', 'white' => [ 'TEXT', $player ];
         process '//td[3]', 'black' => [ 'TEXT', $player ];
         process '//td[3]', 'maybe_bye' => 'TEXT';
-        process '//td[4]', 'board_size' => [ 'TEXT', $board_size ];
-        process '//td[4]', 'handicap' => [ 'TEXT', $handicap ];
+        process '//td[4]', 'setup' => 'TEXT';
         process '//td[5]', 'start_time' => [ 'TEXT', $start_time, $self->date_filter ];
         process '//td[6]', 'result' => 'TEXT';
     };
@@ -60,22 +57,17 @@ sub date_filter {
     $self->{date_filter} ||= sub { $_[0] };
 }
 
+sub result_filter {
+    my $self = shift;
+    $self->{result_filter} = shift if @_;
+    $self->{result_filter} ||= sub { $_[0] };
+}
+
 sub scrape {
     my ( $self, @args ) = @_;
     my $result = $self->SUPER::scrape( @args );
 
-    %$result = (
-        name               => undef,
-        round              => undef,
-        games              => [],
-        byes               => [],
-        previous_round_uri => undef,
-        next_round_uri     => undef,
-        links              => {},
-        %$result,
-    );
-
-    return $result unless @{$result->{games}};
+    return $result unless $result->{games};
 
     my ( @games, @byes );
     for my $game ( @{$result->{games}} ) {
@@ -91,8 +83,35 @@ sub scrape {
         }
     }
 
-    $result->{games} = \@games;
+    my $result_filter = do {
+        my $orig = $self->result_filter;
+        
+        # use SGF-compatible format whenever possible
+        my %canonical = (
+            'W+Res.'  => 'W+Resign',
+            'B+Res.'  => 'B+Resign',
+            'W+Forf.' => 'W+Forfeit',
+            'B+Forf.' => 'B+Forfeit',
+            'Jigo'    => 'Draw',
+        );
+
+        sub {
+            my $r = shift;
+            $orig->( $canonical{$r} || $r );
+        };
+    };
+
+    for my $game ( @games ) {
+        $game->{result}     = $result_filter->( $game->{result} );
+        $game->{setup}      =~ /^(\d+)\x{d7}\d+ (?:H(\d+))?$/;
+        $game->{board_size} = int $1;
+        $game->{handicap}   = int $2 if $2;
+
+        delete $game->{setup};
+    }
+
     $result->{byes}  = \@byes;
+    $result->{games} = \@games;
 
     $result;
 }
@@ -173,6 +192,42 @@ Can be used to get or set an L<LWP::UserAgent> object which is used to
 C<GET> the requested resource. Defaults to the C<LWP::UserAgent> object
 shared by L<Web::Scraper> users (C<$Web::Scraper::UserAgent>).
 
+=item $CodeRef = $tourn_games->date_filter
+
+=item $tourn_games->date_filter( sub { my $date = shift; ... } )
+
+Can be used to get or set a date filter. Defaults to an anonymous subref
+which just returns the given argument (C<sub { $_[0] }>). The callback is
+called with a date string such as C<2014-05-17T19:05Z>.
+The return value is used as the filtered value.
+
+  use Time::Piece qw/gmtime/;
+
+  $tourn_games->date_filter(sub {
+      my $date = shift; # => "2014-05-17T19:05Z"
+      gmtime->strptime( $date, '%Y-%m-%dT%H:%MZ' );
+  });
+
+=item $CodeRef = $tourn_games->result_filter
+
+=item $tourn_games->result_filter( sub { my $result = shift; ... } )
+
+Can be used to get or set a game result filter. Defaults to an anonymous subref
+which just returns the given argument (C<sub { $_[0] }>). The callback is
+called with a game result string such as C<B+Resign>.
+The return value is used as the filtered value.
+
+  $tourn_games->result_filter(sub {
+      my $result = shift;
+
+      # I prefer "B+R" to "B+Resign", 
+      # while both of them are valid SGF-compatible format
+      return 'B+R' if $result eq 'B+Resign';
+      ...
+
+      $result;
+  });
+
 =back
 
 =head2 METHODS
