@@ -35,12 +35,7 @@ sub _build_scraper {
 sub scrape {
     my ( $self, @args ) = @_;
     my $result = $self->SUPER::scrape( @args );
-
-    %$result = (
-        year_index  => [],
-        tournaments => [],
-        %$result,
-    );
+    my $year_index = $result->{year_index};
 
     my @years = do {
        my $_years = delete $result->{_years} || q{};
@@ -50,10 +45,9 @@ sub scrape {
 
     return $result unless @years;
 
-    my $year_index = $result->{year_index};
     for my $i ( 0 .. @years-1 ) {
         next if $year_index->[$i] and $year_index->[$i]->{year} eq $years[$i];
-        splice @$year_index, $i, 0, { year => $years[$i], uri => undef };
+        splice @$year_index, $i, 0, { year => $years[$i] };
         last;
     }
 
